% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{match_pattern}
\alias{match_pattern}
\title{Matches the given pattern to the provided annotations object}
\usage{
match_pattern(annotations, text, pos, use.stems = FALSE,
  ignore.case = TRUE, ignore.punct = FALSE)
}
\arguments{
\item{annotations}{The annotations object genereted by cleanNLP}

\item{text}{The text tags to match, needs to be of the same length as pos.
May be supplied as single string or as vector of strings. Wildcards are supported.}

\item{pos}{The part of speech tags to match, needs to be of the same length as text.
May be supplied as single string or as vector of strings. Wildcards are supported.}

\item{use.stems}{Wheather to use stemmed words for the matching.
Beware that the stem for pronouns is _always_ "-PRON-".
Will currently also return stemmed words.}

\item{ignore.case}{Wheater to ignore case during pattern matching}

\item{ignore.punct}{Wheather to ignore punctuation for the pattern matching.
Note that this refers to the _PUNCT_ pos tag, so it will also ignore any parantheses etc.}
}
\value{
Any matches found in the given text
}
\description{
Matches the given pattern to the provided annotations object
}
\examples{
\dontrun{
# Find all proper nouns following an and

# Both notations are working
text <- "and *"
pos <- c("*", "PROPN")

# Prepare data
articles <- get_data()
annotations <- create_annotations(
  clean_html(articles[articles$Title == "Neil Ashby",4]), 
  articles[articles$Title == "Neil Ashby",2], 
  articles[articles$Title == "Neil Ashby",3]
)

results <- match_pattern(annotations, text, pos, ignore.punct = TRUE)
results
# [1] "and Frequency"   "and Technology"  "and Gravitation"
}
}
